import extend from '../utils/extend.js';

/**
 * 结果键
 */
const resultKey = 'login_result';

/**
 * 信息键
 */
const infoKey = 'login_info';

/**
 * 记住键
 */
const rememberKey = 'login_remember';

/**
 * 用户类
 */
export default {
    /**
     * 获取用户对象
     */
    get() {
        let user = extend.readStorage(resultKey);
        return user;
    },

    /**
     * 设置用户对象
     * @param {object} user 用户对象
     * @returns {boolean} 设置成功标记
     */
    set(user) {
        if (extend.isObject(user)) {
            extend.addStorage(resultKey, user);
            return true;
        }
        return false;
    },

    /**
     * 获取登录信息
     */
    getLoginInfo() {
        let info = extend.readStorage(infoKey);
        return info;
    },

    /**
     * 获取登录信息
     */
    getRemember() {
        let info = extend.readStorage(rememberKey);
        return info;
    },

    /**
     * 设置登录信息
     * @param {object} info 登录信息
     * @param {string} info.LoginName 登录账号
     * @param {string} info.Password 登录密码
     * @returns {boolean} 设置成功标记
     */
    setLoginInfo(info) {
        if (extend.isObject(info)) {
            extend.addStorage(infoKey, info);
            return true;
        }
        return false;
    },

    /**
     * 设置登录信息
     * @param {object} info 登录信息
     * @param {string} info.LoginName 登录账号
     * @param {string} info.Password 登录密码
     * @returns {boolean} 设置成功标记
     */
    setRemember(info) {
        if (extend.isObject(info)) {
            extend.addStorage(rememberKey, info);
            return true;
        }
        return false;
    },

    /**
     * 清除用户信息缓存
     */
    clear() {
        extend.removeStorage(resultKey);
    },

    /**
     * 清除登录信息缓存
     */
    clearLoginInfo() {
        extend.removeStorage(infoKey);
    },

    /**
     * 清除登录信息缓存
     */
    clearRemember() {
        extend.removeStorage(rememberKey);
    }
}